// Run one test with -g + keyword:
//mocha -g syntax

//-----------------------------------------------------------------------------
// Init
//-----------------------------------------------------------------------------

var should  = require('should');
var sinon   = require('sinon');
var startCluster = require('./http-cluster.js')
var sendScriptJob = require('./http-client.js')



//-----------------------------------------------------------------------------
// Tests
//-----------------------------------------------------------------------------



describe('Cluster', function(){

  it('end-to-end: client should return', function(done) {
    startCluster( function(){
      console.log('startCluster callback');

      var scriptObj = {
        script : 'wrapper=function(){ return 1+8 }; RESULT = wrapper()',
        context: {}
      }

      sendScriptJob( scriptObj, function(err, res ){
        console.log('res', res);
        // var parsed = JSON.parse(res)
        // assert.equal(  , "COMPLETE")
        res.result.should.eql( 9 );
        done()
      })
      // sendScriptJob()
    });

  });

  it('end-to-end: default context is inserted', function(done) {
    startCluster( function(){
      console.log('startCluster callback');

      var scriptObj = {
        script : 'wrapper=function(){ console.log(INPUT); return INPUT.a + 8 }; RESULT = wrapper()',
        context: { INPUT : { a: 1 } }
      }

      sendScriptJob( scriptObj, function(err, res ){
        console.log('res', res);
        // var parsed = JSON.parse(res)
        // assert.equal(  , "COMPLETE")
        res.result.should.eql( 9 );
        done()
      })
      // sendScriptJob()
    });

  });

  it('should timeout on infinite loops', function(done) {
    this.timeout(5500);


    startCluster( function(){

      var scriptObj = {
        script: 'while ( true ) {}',
        input: {}
       }
      sendScriptJob( scriptObj, function(err, res ){
        console.log('err', err);
        err.statusCode.should.eql( 500 );
        done()
      })

    })
  });

  it('end-to-end: handle errors correctly', function(done) {
    startCluster( function(){
      console.log('startCluster callback');

      var scriptObj = {
        script : 'wrapper=function(){ \
          \nreturn request({ url: "http://mockbin.org/bin/17889536-56e3-498d-9caa-be279a7e5a8d/" }).then(function( body ){ RESULT = body; done()})\
          \n }; RESULT = wrapper()',
        context: { INPUT : { a: 1 } }
      }

      sendScriptJob( scriptObj, function(err, res ){
        console.log('res', res);
        console.log('err', err);

        // var parsed = JSON.parse(res)
        // assert.equal(  , "COMPLETE")
        err.status.should.eql( 'ERROR' );
        err.result.should.eql( 'ReferenceError : request is not defined');

        done()
      })
      // sendScriptJob()
    });

  });

});
